"""
Test configuration to ensure the package under test is importable.
Adds the repository root's `src` directory to `sys.path` so `import ptspy` works
for both new and legacy tests.
"""
from __future__ import annotations

import sys
from pathlib import Path

ROOT = Path(__file__).resolve().parents[1]
SRC = ROOT / "src"

if SRC.as_posix() not in sys.path:
    sys.path.insert(0, SRC.as_posix())
